import pywal
import os
import typer
from time import sleep

config_folder = f"/home/{os.getlogin()}/.config/auto-ricer"
cli = typer.Typer(add_completion=True)


@cli.command()
def from_img(wallpaper: str):

    if not os.path.isdir(config_folder):
        install_theme()
    colors_from_img = pywal.colors.get(wallpaper)

    colors_list = list(colors_from_img["colors"].values())

    final_colors = pywal.colors.colors_to_dict(colors_list, wallpaper)
    pywal.export.every(final_colors)
    pywal.sequences.send(final_colors)

    pywal.reload.xrdb()

    os.system(f"sh /home/{os.getlogin()}/.config/bspwm/bspwmrc")
    sleep(1)
    pywal.wallpaper.set_wm_wallpaper(wallpaper)

    fix_gtk_colors()

    oomox_file_path = f"/home/{os.getlogin()}/.cache/wal/colors-oomox"
    gtk_theme_command = f"cd {config_folder}/theme_materia/materia-theme && chmod +x change_color.sh && ./change_color.sh -o auto-ricer -t /home/{os.getlogin()}/.themes {oomox_file_path}"
    os.system(gtk_theme_command)

    icons_theme_command = f"cd {config_folder}/icons_papirus && chmod +x change_color.sh && ./change_color.sh -o auto-ricer -d /home/{os.getlogin()}/.icons/auto-ricer {oomox_file_path}"
    os.system(icons_theme_command)


def fix_gtk_colors():
    oomox_colors = open(f"/home/{os.getlogin()}/.cache/wal/colors-oomox", "r").read()
    oomox_colors = oomox_colors.splitlines()
    bg_color = oomox_colors[1].strip("BG=")
    oomox_colors[9] = f"BTN_BG={bg_color}"
    oomox_colors = "\n".join(oomox_colors)

    with open(f"/home/{os.getlogin()}/.cache/wal/colors-oomox", "w") as f:
        f.write(oomox_colors)


def install_theme():
    os.system(
        f"mkdir {config_folder} && cd {config_folder} && git clone https://github.com/AbdelrhmanNile/auto-ricer.git"
    )
    os.system(
        f"cd /home/{os.getlogin()}/.config/auto-ricer/auto-ricer && cp /gtk/. /home/{os.getlogin()}/.config/auto-ricer/"
    )
    os.system(f"rm -r /home/{os.getlogin()}/.config/auto-ricer/auto-ricer")


if __name__ == "__main__":
    cli()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['auto_ricer']

package_data = \
{'': ['*']}

install_requires = \
['pywal>=3.3.0,<4.0.0', 'typer>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['auto-ricer = auto_ricer.autoricer:cli']}

setup_kwargs = {
    'name': 'auto-ricer',
    'version': '0.1.2.post4',
    'description': '',
    'long_description': '## auto ricer\nA simple script to automatically rice bspwm, polybar, gtk, and more.',
    'author': 'AbdelrhmanNile',
    'author_email': 'abdelrhmannile@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
